LocoAddress

Struct LocoAddress 

pub struct LocoAddress(/* private fields */);

Implementations

Source

impl LocoAddress

pub fn new(addr: u8) -> Self

Constructs short DCC locomotive address

pub fn new_long(addr: u16) -> Self

Constructs long DCC locomotive address

pub fn is_long(&self) -> bool

Get the address type

Returns true when the address is 14 bits long

pub fn as_bytes(&self) -> [u8; 2]

Returns the address data as two octets in big endian

pub fn as_bytes_sanitized(&self) -> [u8; 2]

Returns the address data as two octets in big endian with sanitization that is useful for constructing CBUS packets

7 bit addresses have most significant octet set to 0. 14 bit addresses have bits 6,7 of most significant octet set to 1.