#[repr(u8)]pub enum CabDataCode {
CabSignalling = 1,
}Expand description
Defines the meaning of the remaining 3 bytes of the CABDAT message
Variants
CabSignalling = 1
CABSIG Transmitted by a layout control system to send signal aspects to be displayed on a cab handset as cab signalling.