ModuleParam

Enum ModuleParam 

#[repr(u8)]
pub enum ModuleParam {
Show 15 variants ModuleParameterCount = 0, ModuleManufacturer = 1, MinorVersion = 2, ModuleType = 3, MaxEventCount = 4, EventVariableCount = 5, NodeVariableCount = 6, MajorVersion = 7, NodeFlags = 8, CpuId = 9, BusType = 10, LoadAddress = 11, CpuManufacturerId = 15, CpuManufacturer = 19, BetaVersion = 20,
}
Parameter index numbers (readable by OPC_RQNPN, returned in OPC_PARAN) Index numbers count from 1, subtract 1 for offset into parameter block Note that RQNPN with index 0 returns the parameter count

Variants



ModuleParameterCount = 0

Number of parameters



ModuleManufacturer = 1

Manufacturer id



MinorVersion = 2

Minor version (single alphabetic character)



ModuleType = 3

Module type code



MaxEventCount = 4

Number of events supported



EventVariableCount = 5

Event variables per event



NodeVariableCount = 6

Number of Node variables



MajorVersion = 7

Major version (numeric)



NodeFlags = 8

Node flags



CpuId = 9

Processor type



BusType = 10

Bus type



LoadAddress = 11

load address, 4 bytes



CpuManufacturerId = 15

CPU manufacturer’s id as read from the chip config space, 4 bytes (note - read from cpu at runtime, so not included in checksum)



CpuManufacturer = 19

CPU manufacturer code



BetaVersion = 20

Beta revision (numeric), or 0 if release