pub struct ModuleFlags(/* private fields */);Expand description
Flags in node parameter FLAGS
Implementations
Sourceimpl ModuleFlags
impl ModuleFlags
Sourcepub const EventsUnsupported: Self
pub const EventsUnsupported: Self
Module doesn’t support events
Sourcepub const EventConsumer: Self
pub const EventConsumer: Self
Module is a consumer of events
Sourcepub const EventProducer: Self
pub const EventProducer: Self
Module is a producer of events
Sourcepub const EventCombi: Self
pub const EventCombi: Self
Module is both a consumer and producer of events
Sourcepub const NormalMode: Self
pub const NormalMode: Self
Module is in Normal mode (VLCB)
Sourcepub const Bootloader: Self
pub const Bootloader: Self
Module supports the FCU bootloader protocol
Sourcepub const ConsumeOwnEvents: Self
pub const ConsumeOwnEvents: Self
Module can consume its own events
Sourcepub const ServiceDiscovery: Self
pub const ServiceDiscovery: Self
Module supports Service Discovery (Deprecated in favour of PF_VLCB.)
Sourceimpl ModuleFlags
impl ModuleFlags
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Self
pub const fn from_bits_retain(bits: u8) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ModuleFlags
impl ModuleFlags
Sourcepub const fn iter(&self) -> Iter<ModuleFlags>
pub const fn iter(&self) -> Iter<ModuleFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ModuleFlags>
pub const fn iter_names(&self) -> IterNames<ModuleFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.